/*
     File:       DICOM_Toolkit_Versions.h

     Contains:   Escape DICOM Toolkit Initialization Version Definitions.

     Copyright:  (c)2002-2004 by Escape Information Services, all rights reserved.

     Bugs?       For support or bug reports please send email to support@escape.gr
 
*/

#ifndef __DICOM_TOOLKIT_VERSIONS__
#define __DICOM_TOOLKIT_VERSIONS__
    
/* 
    Note:
    ----
    Resource (.r) files should include <MacTypes.r> before including this file
    C/C++ header (.h) files should inlcude <MacTypes.h> before including this file
    
    Final version constants are formatted as a NumVersion struct, defined in <MacTypes.h>
*/

#ifdef __cplusplus
extern "C" {
#endif
	
	// Base version constants for entire toolkit
	
    #define TOOLKIT_VERSION_MAJOR           0x02
    #define TOOLKIT_VERSION_MINOR_HI        0x03
    #define TOOLKIT_VERSION_BUG             0x01
    #define TOOLKIT_VERSION_MINOR_AND_BUG   ((TOOLKIT_VERSION_MINOR_HI << 4) | TOOLKIT_VERSION_BUG)
    #define TOOLKIT_VERSION_STAGE           finalStage
    #define TOOLKIT_VERSION_NOREL           0x00
    #define TOOLKIT_VERSION_REGION          verUS
    #define TOOLKIT_SHORT_VERSION           "2.3.1"
    #define TOOLKIT_LONG_VERSION            "Escape DICOM Toolkit v" TOOLKIT_SHORT_VERSION
	
	// Version constants for parser component
	
    #define PARSER_VERSION_MAJOR           0x03
    #define PARSER_VERSION_MINOR_HI        0x02
    #define PARSER_VERSION_BUG             0x00
    #define PARSER_VERSION_MINOR_AND_BUG   ((PARSER_VERSION_MINOR_HI << 4) | PARSER_VERSION_BUG)
    #define PARSER_VERSION_STAGE           TOOLKIT_VERSION_STAGE
    #define PARSER_VERSION_NOREL           0x00
    #define PARSER_VERSION_REGION          verUS
    #define PARSER_SHORT_VERSION           "3.2"
    #define PARSER_LONG_VERSION            "Escape DICOM Toolkit Parser Component v" PARSER_SHORT_VERSION
	
	// Version constants for decompressor component
	
    #define CODEC_VERSION_MAJOR           0x03
    #define CODEC_VERSION_MINOR_HI        0x06
    #define CODEC_VERSION_BUG             0x00
    #define CODEC_VERSION_MINOR_AND_BUG   ((CODEC_VERSION_MINOR_HI << 4) | CODEC_VERSION_BUG)
    #define CODEC_VERSION_STAGE           TOOLKIT_VERSION_STAGE
    #define CODEC_VERSION_NOREL           0x00
    #define CODEC_VERSION_REGION          verUS
    #define CODEC_SHORT_VERSION           "3.6"
    #define CODEC_LONG_VERSION            "Escape DICOM Toolkit Decompressor Component v" CODEC_SHORT_VERSION
	
	// Version constants for graphics importer component
	
    #define GRAPHICS_IMPORTER_VERSION_MAJOR           0x03
    #define GRAPHICS_IMPORTER_VERSION_MINOR_HI        0x04
    #define GRAPHICS_IMPORTER_VERSION_BUG             0x00
    #define GRAPHICS_IMPORTER_VERSION_MINOR_AND_BUG   ((GRAPHICS_IMPORTER_VERSION_MINOR_HI << 4) | GRAPHICS_IMPORTER_VERSION_BUG)
    #define GRAPHICS_IMPORTER_VERSION_STAGE           TOOLKIT_VERSION_STAGE
    #define GRAPHICS_IMPORTER_VERSION_NOREL           0x00
    #define GRAPHICS_IMPORTER_VERSION_REGION          verUS
    #define GRAPHICS_IMPORTER_SHORT_VERSION           "3.4"
    #define GRAPHICS_IMPORTER_LONG_VERSION            "Escape DICOM Toolkit Graphics Importer Component v" GRAPHICS_IMPORTER_SHORT_VERSION
	
	// Version constants for movie importer component
	
    #define MOVIE_IMPORTER_VERSION_MAJOR           0x03
    #define MOVIE_IMPORTER_VERSION_MINOR_HI        0x04
    #define MOVIE_IMPORTER_VERSION_BUG             0x00
    #define MOVIE_IMPORTER_VERSION_MINOR_AND_BUG   ((MOVIE_IMPORTER_VERSION_MINOR_HI << 4) | MOVIE_IMPORTER_VERSION_BUG)
    #define MOVIE_IMPORTER_VERSION_STAGE           TOOLKIT_VERSION_STAGE
    #define MOVIE_IMPORTER_VERSION_NOREL           0x00
    #define MOVIE_IMPORTER_VERSION_REGION          verUS
    #define MOVIE_IMPORTER_SHORT_VERSION           "3.4"
    #define MOVIE_IMPORTER_LONG_VERSION            "Escape DICOM Toolkit Movie Importer Component v" MOVIE_IMPORTER_SHORT_VERSION
	
	// Version constants for graphics exporter component
	
    #define GRAPHICS_EXPORTER_VERSION_MAJOR           0x01
    #define GRAPHICS_EXPORTER_VERSION_MINOR_HI        0x03
    #define GRAPHICS_EXPORTER_VERSION_BUG             0x00
    #define GRAPHICS_EXPORTER_VERSION_MINOR_AND_BUG   ((GRAPHICS_EXPORTER_VERSION_MINOR_HI << 4) | GRAPHICS_EXPORTER_VERSION_BUG)
    #define GRAPHICS_EXPORTER_VERSION_STAGE           TOOLKIT_VERSION_STAGE
    #define GRAPHICS_EXPORTER_VERSION_NOREL           0x00
    #define GRAPHICS_EXPORTER_VERSION_REGION          verUS
    #define GRAPHICS_EXPORTER_SHORT_VERSION           "1.3"
    #define GRAPHICS_EXPORTER_LONG_VERSION            "Escape DICOM Toolkit Graphics Exporter Component v" GRAPHICS_EXPORTER_SHORT_VERSION
	
	// Version constants for VOI Blitter component
	
    #define DICOM_VOIBLITTER_VERSION_MAJOR           0x01
    #define DICOM_VOIBLITTER_VERSION_MINOR_HI        0x01
    #define DICOM_VOIBLITTER_VERSION_BUG             0x00
    #define DICOM_VOIBLITTER_VERSION_MINOR_AND_BUG   ((DICOM_VOIBLITTER_VERSION_MINOR_HI << 4) | DICOM_VOIBLITTER_VERSION_BUG)
    #define DICOM_VOIBLITTER_VERSION_STAGE           TOOLKIT_VERSION_STAGE
    #define DICOM_VOIBLITTER_VERSION_NOREL           0x00
    #define DICOM_VOIBLITTER_VERSION_REGION          verUS
    #define DICOM_VOIBLITTER_SHORT_VERSION           "1.1"
    #define DICOM_VOIBLITTER_LONG_VERSION            "Escape DICOM Toolkit VOI Blitter Component v" DICOM_VOIBLITTER_SHORT_VERSION
	
	// Final version constants
	
	#define DICOM_TOOLKIT_VERSION  			 ((TOOLKIT_VERSION_MAJOR << 24) | (TOOLKIT_VERSION_MINOR_AND_BUG << 16) | (TOOLKIT_VERSION_STAGE << 8)  | TOOLKIT_VERSION_NOREL)
	#define DICOM_PARSER_VERSION             ((PARSER_VERSION_MAJOR               << 16) | PARSER_VERSION_MINOR_HI)
	#define DICOM_CODEC_VERSION              ((CODEC_VERSION_MAJOR                << 16) | CODEC_VERSION_MINOR_HI)
	#define DICOM_GRAPHICS_IMPORTER_VERSION  ((GRAPHICS_IMPORTER_VERSION_MAJOR    << 16) | GRAPHICS_IMPORTER_VERSION_MINOR_HI)
	#define DICOM_MOVIE_IMPORTER_VERSION     ((MOVIE_IMPORTER_VERSION_MAJOR       << 16) | MOVIE_IMPORTER_VERSION_MINOR_HI)    
	#define DICOM_GRAPHICS_EXPORTER_VERSION  ((GRAPHICS_EXPORTER_VERSION_MAJOR    << 16) | GRAPHICS_EXPORTER_VERSION_MINOR_HI)
	#define DICOM_VOIBLITTER_VERSION  		 ((DICOM_VOIBLITTER_VERSION_MAJOR     << 16) | DICOM_VOIBLITTER_VERSION_MINOR_HI)
	
	#ifdef __MACTYPES__
	/*!
	    @enum DTkVersionConstants
	    @abstract Encoded version numbers of the various parts of DICOM Toolkit
	    @constant kDICOM_ToolkitVersion         Version of entire toolkit 
	    @constant kDICOM_ParserVersion          Version of toolkit's parser component
	    @constant kDICOM_CodecVersion           Version of toolkit's decompressor component
	    @constant kDICOM_GraphicsImportVersion  Version of toolkit's graphics importer component
	    @constant kDICOM_MovieImportVersion     Version of toolkit's movie importer component
	    @constant kDICOM_GraphicsExportVersion  Version of toolkit's graphics exporter component
	    @constant kDICOM_VOIBlitterVersion	    Version of toolkit's VOI Blitter component
	    @discussion <ul>
	                    <li>The version constant of the entire toolkit is encoded in NumVersion format, which is defined in &lt;MacTypes.h&gt;.<br>
	                    <li>The version contants of individual components are encoded as a 16 bit high part, representing the component 
	                        interface version, followed by a 16 bit low part, representing the minor component version.
	                </ul>
	*/
		
		typedef enum
		{
	    	kDICOM_ToolkitVersion		 = DICOM_TOOLKIT_VERSION,
		    kDICOM_ParserVersion         = DICOM_PARSER_VERSION,
			kDICOM_CodecVersion          = DICOM_CODEC_VERSION,
	    	kDICOM_GraphicsImportVersion = DICOM_GRAPHICS_IMPORTER_VERSION,
	    	kDICOM_MovieImportVersion    = DICOM_MOVIE_IMPORTER_VERSION,
	    	kDICOM_GraphicsExportVersion = DICOM_GRAPHICS_EXPORTER_VERSION,
	    	kDICOM_VOIBlitterVersion	 = DICOM_VOIBLITTER_VERSION
		} DTkVersionConstants;
	#endif

#ifdef __cplusplus
}
#endif

#endif // __DICOM_TOOLKIT_VERSIONS__
