/*
     File:       DICOM_Toolkit.h

     Contains:   Escape DICOM Toolkit Initialization Interfaces.

     Copyright:  (c)2002-2004 by Escape Information Services, all rights reserved.

     Bugs?       For support or bug reports please send email to support@escape.gr
 
*/

#ifndef __DICOM_TOOLKIT__
#define __DICOM_TOOLKIT__

#if TARGET_API_MAC_OSX
	#include <Carbon/Carbon.h>
#else

	#ifndef __MACTYPES__
		#include <MacTypes.h>
	#endif
	#ifndef __COMPONENTS__
		#include <Components.h>
	#endif
#endif

#ifndef __DICOM_TOOLKIT_VERSIONS__
	#include "DICOM_Toolkit_Versions.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT
#pragma import on
#endif

/*!
	@header DICOM_Toolkit.h
    @discussion This header includes the initialization and 
    			termination calls of the DICOM Toolkit API.
*/


#pragma export on

#if PRAGMA_ENUM_ALWAYSINT
    #if defined(__fourbyteints__) && !__fourbyteints__ 
        #define __DICOM_TOOLKIT_TYPES__RESTORE_TWOBYTEINTS
        #pragma fourbyteints on
    #endif
    #pragma enumsalwaysint on
#elif PRAGMA_ENUM_OPTIONS
    #pragma option enum=int
#elif PRAGMA_ENUM_PACK
    #if __option(pack_enums)
        #define __DICOM_TOOLKIT_TYPES__RESTORE_PACKED_ENUMS
        #pragma options(!pack_enums)
    #endif
#endif


/*!
    @enum DTkInitializationFlags
	@abstract Flags for use with DICOMToolkitInitialize that control which of the toolkit's components will be registered and activated
	@constant kDTkInitFlag_DoNotActivateGraphicImporter Specifies that the DICOM Graphic Importer will not be activated
	@constant kDTkInitFlag_DoNotActivateMovieImporter   Specifies that the DICOM Movie Importer will not be activated
	@constant kDTkInitFlag_DoNotActivateParser          Specifies that the DICOM Parser will not be activated
	@constant kDTkInitFlag_DoNotActivateDecompressor    Specifies that the DICOM Decompressor will not be activated
	@constant kDTkInitFlag_DoNotActivateVOIBlitterComp  Specifies that the DICOM VOI Blitter Component will not be activated
	@constant kDTkInitFlag_DoNotActivateGraphicExporter Specifies that the DICOM Graphic Exporter (Anonymizer) will not be activated
*/
typedef enum
{
	kDTkInitFlag_ActivateAllComponents   = 0,
	kDTkInitFlag_DoNotActivateGraphicImporter  = 1 << 0,
	kDTkInitFlag_DoNotActivateMovieImporter    = 1 << 1,
	kDTkInitFlag_DoNotActivateParser           = 1 << 2,
	kDTkInitFlag_DoNotActivateDecompressor     = 1 << 3,
	kDTkInitFlag_DoNotActivateVOIBlitterComp   = 1 << 4,
	kDTkInitFlag_DoNotActivateGraphicExporter  = 1 << 5	
} DTkInitializationFlags;

/*!
	@function DICOMToolkitInitialize
	@abstract Initializes and activates the toolkit.
	@discussion Before any of the functions in DICOM Toolkit can be used, 
				it must be initialized by calling this function, which registers the four components
				packaged in the toolkit's shared library, making them available to QuickTime, the application
				and each other.
				The DICOMToolkitInitialize call is also used to activate the toolkit with an appropriate license key formatted as a Pascal string. When a wrong or no license key is entered the toolkit runs in evaluation mode. Except for the following limitations, the toolkit is fully functional when in evaluation mode:
				<OL>
				<LI>Strings returned by the toolkit's parser commands are replaced with a demo message.
				<LI>Pixel maps returned by the toolkit's codec commands have a demo message burnt into them.
				</OL>
	@param licenceKey [I] The license key formatted as a Pascal string.
	@param flags      [I] Currently used to specify which toolkit components not to activate using a combination of the flags defined in the DICOMToolkitInitializationFlags enumeration. When flags = 0 all components are activated.
	@result Error code
*/
ComponentResult DICOMToolkitInitialize(
                                        unsigned char *licenceKey, 
                                        UInt32 flags );

/*!
	@function DICOMToolkitTerminate
	@abstract Unregisters toolkit's components and releases resources they occupied.
	@discussion  When services of the toolkit are no longer required, 
				 use this function unregister its components and release the resources occupied by it.
	@result Error code
*/
ComponentResult DICOMToolkitTerminate(void);


#if PRAGMA_ENUM_ALWAYSINT
    #pragma enumsalwaysint reset
    #ifdef __DICOM_TOOLKIT_TYPES__RESTORE_TWOBYTEINTS
        #pragma fourbyteints off
    #endif
#elif PRAGMA_ENUM_OPTIONS
    #pragma option enum=reset
#elif defined(__DICOM_TOOLKIT_TYPES__RESTORE_PACKED_ENUMS)
    #pragma options(pack_enums)
#endif

#pragma export off

#ifdef PRAGMA_IMPORT_OFF
#pragma import off
#elif PRAGMA_IMPORT
#pragma import reset
#endif

#ifdef __cplusplus
}
#endif

#endif // __DICOM_TOOLKIT__
